Supported Python Versions
=========================

Both CLI and library are written in python.


Python 2
--------

Project supports python 2.7. Python 2 will be supported as long as libraries project depends on are reasonably available and possible to support with python 3 as well.


Python 3
--------

Following versions of python 3 are supported:

- 3.6
- 3.7
- 3.8
- 3.9
- 3.10

Python 3 support will more or less follow python 3 lifecycle - if new version is released project should run on it as well. As python version goes end of life from upstream the support by the project will fade away as well. See `Status of Python branches` for upstream lifecycle.


.. _`Status of Python branches`: https://devguide.python.org/#status-of-python-branches
